Exception raised when unable to connect to the Ollama server.
The message includes a reminder to start Ollama and a download link.
@type t() :: %Ollixir.ConnectionError{ __exception__: true, message: String.t(), original_error: term(), reason: term() }